Index: src/arm64/full-codegen-arm64.cc |
diff --git a/src/arm64/full-codegen-arm64.cc b/src/arm64/full-codegen-arm64.cc |
index 75a6500ae8ae8fa69f6b4b7526ff28c5570d7ef5..198e781956ae6daa2cc0ee6ad5a5d71e94b9b5c9 100644 |
--- a/src/arm64/full-codegen-arm64.cc |
+++ b/src/arm64/full-codegen-arm64.cc |
@@ -3506,8 +3506,8 @@ void FullCodeGenerator::EmitGetCachedArrayIndex(CallRuntime* expr) { |
} |
-void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
- ASM_LOCATION("FullCodeGenerator::EmitFastAsciiArrayJoin"); |
+void FullCodeGenerator::EmitFastOneByteArrayJoin(CallRuntime* expr) { |
+ ASM_LOCATION("FullCodeGenerator::EmitFastOneByteArrayJoin"); |
ZoneList<Expression*>* args = expr->arguments(); |
DCHECK(args->length() == 2); |
@@ -3559,7 +3559,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// Get the FixedArray containing array's elements. |
__ Ldr(elements, FieldMemOperand(array, JSArray::kElementsOffset)); |
// Check that all array elements are sequential ASCII strings, and |
// accumulate the sum of their lengths. |
__ Mov(string_length, 0); |
__ Add(element, elements, FixedArray::kHeaderSize - kHeapObjectTag); |
@@ -3574,14 +3574,14 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// elements_end: Array end. |
if (FLAG_debug_code) { |
__ Cmp(array_length, 0); |
- __ Assert(gt, kNoEmptyArraysHereInEmitFastAsciiArrayJoin); |
+ __ Assert(gt, kNoEmptyArraysHereInEmitFastOneByteArrayJoin); |
} |
__ Bind(&loop); |
__ Ldr(string, MemOperand(element, kPointerSize, PostIndex)); |
__ JumpIfSmi(string, &bailout); |
__ Ldr(scratch1, FieldMemOperand(string, HeapObject::kMapOffset)); |
__ Ldrb(scratch1, FieldMemOperand(scratch1, Map::kInstanceTypeOffset)); |
- __ JumpIfInstanceTypeIsNotSequentialAscii(scratch1, scratch2, &bailout); |
+ __ JumpIfInstanceTypeIsNotSequentialOneByte(scratch1, scratch2, &bailout); |
__ Ldrsw(scratch1, |
UntagSmiFieldMemOperand(string, SeqOneByteString::kLengthOffset)); |
__ Adds(string_length, string_length, scratch1); |
@@ -3603,11 +3603,11 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// string_length: Sum of string lengths (not smi). |
// elements: FixedArray of strings. |
// Check that the separator is a flat ASCII string. |
__ JumpIfSmi(separator, &bailout); |
__ Ldr(scratch1, FieldMemOperand(separator, HeapObject::kMapOffset)); |
__ Ldrb(scratch1, FieldMemOperand(scratch1, Map::kInstanceTypeOffset)); |
- __ JumpIfInstanceTypeIsNotSequentialAscii(scratch1, scratch2, &bailout); |
+ __ JumpIfInstanceTypeIsNotSequentialOneByte(scratch1, scratch2, &bailout); |
// Add (separator length times array_length) - separator length to the |
// string_length to get the length of the result string. |
@@ -3627,13 +3627,13 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// separator: Separator string |
// string_length: Length of result string (not smi) |
// array_length: Length of the array (not smi). |
- __ AllocateAsciiString(result, string_length, scratch1, scratch2, scratch3, |
- &bailout); |
+ __ AllocateOneByteString(result, string_length, scratch1, scratch2, scratch3, |
+ &bailout); |
// Prepare for looping. Set up elements_end to end of the array. Set |
// result_pos to the position of the result where to write the first |
// character. |
// TODO(all): useless unless AllocateAsciiString trashes the register. |
__ Add(elements_end, element, Operand(array_length, LSL, kPointerSizeLog2)); |
__ Add(result_pos, result, SeqOneByteString::kHeaderSize - kHeapObjectTag); |
@@ -3661,7 +3661,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// One-character separator case |
__ Bind(&one_char_separator); |
// Replace separator with its ASCII character value. |
__ Ldrb(separator, FieldMemOperand(separator, SeqOneByteString::kHeaderSize)); |
// Jump into the loop after the code that copies the separator, so the first |
// element is not preceded by a separator |
@@ -3672,7 +3672,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// result_pos: the position to which we are currently copying characters. |
// element: Current array element. |
// elements_end: Array end. |
// separator: Single separator ASCII char (in lower byte). |
// Copy the separator character to the result. |
__ Strb(separator, MemOperand(result_pos, 1, PostIndex)); |
@@ -3559,7 +3559,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// Get the FixedArray containing array's elements. |
__ Ldr(elements, FieldMemOperand(array, JSArray::kElementsOffset)); |
- // Check that all array elements are sequential ASCII strings, and |
+ // Check that all array elements are sequential one-byte strings, and |
// accumulate the sum of their lengths. |
__ Mov(string_length, 0); |
@@ -3603,11 +3603,11 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// string_length: Sum of string lengths (not smi). |
// elements: FixedArray of strings. |
- // Check that the separator is a flat ASCII string. |
+ // Check that the separator is a flat one-byte string. |
__ JumpIfSmi(separator, &bailout); |
__ Ldr(scratch1, FieldMemOperand(separator, HeapObject::kMapOffset)); |
@@ -3627,13 +3627,13 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// result_pos to the position of the result where to write the first |
// character. |
- // TODO(all): useless unless AllocateAsciiString trashes the register. |
+ // TODO(all): useless unless AllocateOneByteString trashes the register. |
__ Add(elements_end, element, Operand(array_length, LSL, kPointerSizeLog2)); |
__ Add(result_pos, result, SeqOneByteString::kHeaderSize - kHeapObjectTag); |
@@ -3661,7 +3661,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// One-character separator case |
__ Bind(&one_char_separator); |
- // Replace separator with its ASCII character value. |
+ // Replace separator with its one-byte character value. |
__ Ldrb(separator, FieldMemOperand(separator, SeqOneByteString::kHeaderSize)); |
// Jump into the loop after the code that copies the separator, so the first |
@@ -3672,7 +3672,7 @@ void FullCodeGenerator::EmitFastAsciiArrayJoin(CallRuntime* expr) { |
// element: Current array element. |
// elements_end: Array end. |
- // separator: Single separator ASCII char (in lower byte). |
+ // separator: Single separator one-byte char (in lower byte). |
// Copy the separator character to the result. |
__ Strb(separator, MemOperand(result_pos, 1, PostIndex)); |